#========================================================================================
# package      DE_EPAGES::Product::API::Tools
# base         Exporter
# state        public
#----------------------------------------------------------------------------------------
# description  A collection of helper functions
#========================================================================================
package DE_EPAGES::Product::API::Tools;
use base Exporter;

use DE_EPAGES::Core::API::Object::DateTimeFormatter;
use DE_EPAGES::XML::API::DateTimeFormatXML;

use strict;



our @EXPORT_OK = qw (
    MergeUpdatedProductsResults
    ConvertDateTimeForEpJ
);



#========================================================================================
# function     MergeUpdatedProductsResults
# state        public
#----------------------------------------------------------------------------------------
# syntax       MergeUpdatedProductsResults( $aArray1, $aArray2 );
#----------------------------------------------------------------------------------------
# description  Merges the two arrays with updated products. If one product id appears
#               in both arrays, the one with the latest date will be taken.
#----------------------------------------------------------------------------------------
# input        $aArray1 | Array 1 to merge | refarray
# input        $aArray1 | Array 2 to merge | refarray
# return       Merged arrays | refarray
#========================================================================================
sub MergeUpdatedProductsResults {
    my ($aArray1, $aArray2) = @_;

    my @Array1 = map {$_->[0], $_->[1]} @$aArray1;
    my $hHash1 = {@Array1};

    my @Array2 = map {$_->[0], $_->[1]} @$aArray2;
    my $hHash2 = {@Array2};

    my $hResults = $hHash1;
    my $Formatter = DE_EPAGES::Core::API::Object::DateTimeFormatter->new();

    for my $Array2Id (keys %$hHash2) {
        if(exists $hHash1->{$Array2Id}) {

            my $DateInArray1 = $hHash1->{$Array2Id};
            my $DateTimeInArray1 = $Formatter->parse_datetime($DateInArray1, 'datetime', '%Y-%m-%d %H:%M:%S' );
            my $DateInArray2 = $hHash2->{$Array2Id};
            my $DateTimeInArray2 = $Formatter->parse_datetime($DateInArray2, 'datetime', '%Y-%m-%d %H:%M:%S' );

            if($DateTimeInArray1->compare($DateTimeInArray2) < 0) {
                $hResults->{$Array2Id} = $hHash2->{$Array2Id};
            }
        } else {
            $hResults->{$Array2Id} = $hHash2->{$Array2Id};
        }
    }

    my @ResultKeys = keys %$hResults;
    my @Results = map { [$_, $hResults->{$_}] } @ResultKeys;

    return \@Results;
}



#========================================================================================
# function     ConvertDateTimeForEpJ
# state        public
#----------------------------------------------------------------------------------------
# syntax       ConvertDateTimeForEpJ( $DateTimeString );
#----------------------------------------------------------------------------------------
# description  Converts ep6 datetime strings to epj UTC datetime strings.
#----------------------------------------------------------------------------------------
# input        $DateTimeString | ep6 datetime string | string
# return       epj UTC datetime string | string
#========================================================================================
sub ConvertDateTimeForEpJ {
    my ($DateTimeString) = @_;

    my $Formatter = DE_EPAGES::Core::API::Object::DateTimeFormatter->new();
    my $DateTime = $Formatter->parse_datetime($DateTimeString, 'datetime', '%Y-%m-%d %H:%M:%S' );
    my $DF = DE_EPAGES::XML::API::DateTimeFormatXML->new();
    my $DateInUTC = $DF->format_datetime( $DateTime, 'UTC' );

    return $DateInUTC;
}

1;
