#==============================================================================
# package      DE_EPAGES::Product::API::WebService::ProductService10
# base         DE_EPAGES::Product::API::WebService::ProductService9
# state        public
# description  Implements the Product WebService.
#==============================================================================
package DE_EPAGES::Product::API::WebService::ProductService10;
use base DE_EPAGES::Product::API::WebService::ProductService9;

use strict;
use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::Core::API::File qw ( ConvertFileNameChars WriteFile );

sub new {
    my $self = shift;
    my @Options = @_;
    $self->SUPER::new((
        'ServiceUrn' => 'urn://epages.de/WebService/ProductService/2012/07',
        'ServiceTypesUrn' => 'urn://epages.de/WebService/ProductTypes/2012/07',
        @Options,
    ));
}

#========================================================================================
# function     setAttributeValues
# state        private
#----------------------------------------------------------------------------------------
# syntax       $self->setAttributeValues( $object, $ahAttributes )
#----------------------------------------------------------------------------------------
# description  No WebService-Method!
#               Sets attributes of a object.
#               inherites WebService::API::WebService::BaseService::setAttributeValues
#----------------------------------------------------------------------------------------
# input        $object | object to update | object
# input        $ahAttributes | list of attributes, with this keys
#                             <ul>
#                               <li>Name            - attribute id - string
#                               <li>Value           - attribute value to set - string
#                               <li>LocalizedValues - localized attribute value to set - loc. string
#                               <li>FileContent     - file content to upload if type of attribute file - binary
#                             </ul> | ref.array.hash
#========================================================================================
sub setAttributeValues {
    my $self = shift;
    my ($object, $ahAttributes) = @_;

    return undef unless $ahAttributes;

    foreach my $hAttribute (@$ahAttributes) {
        my $attributeId = $hAttribute->{'Name'};

        Error('ATTRIBUTE_DOES_NOT_EXIST', {
            'Attribute' => $attributeId,
            'Class' => $object->class->alias,
        }) unless $object->class->existsAttribute($attributeId);

        my $attribute = $object->class->attribute($attributeId);
        my $type = $attribute->get('Type');

        if ( $type eq 'File' ) {
            if ( $hAttribute->{'FileContent'} ) {
                $hAttribute->{'Value'} = ConvertFileNameChars($hAttribute->{'Value'});
                my $FileName = $object->get('PublicPath').'/'.$hAttribute->{'Value'};

                #upload public file
                WriteFile($FileName, \$hAttribute->{'FileContent'}, { binary=>1, create_directory=>1} );
                $hAttribute->{'FileName'} = $FileName;
            }
        }
        elsif ( $type eq 'LocalizedFile' ) {
            foreach my $LocalizedFile (@{$hAttribute->{'LocalizedValues'}}){
                if ( $LocalizedFile->{'FileContent'}) {
                    $LocalizedFile->{'Value'} = ConvertFileNameChars($LocalizedFile->{'Value'});
                    my $FileName = $object->get('PublicPath').'/'.$LocalizedFile->{'Value'};

                    #upload public file
                    WriteFile($FileName, \$LocalizedFile->{'FileContent'}, { binary=>1, create_directory=>1} );
                    $LocalizedFile->{'FileName'} = $FileName;
                }
            }
        }
    }

    $self->SUPER::setAttributeValues($object, $ahAttributes);
}

1;
