#========================================================================================
# package      main
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for Logger
#========================================================================================
package main;
use base DE_EPAGES::Test::API::UnitTest::Test;
use Test::More;
use Test::Exception;
use DE_EPAGES::Test::Mock::Mockify qw (WasCalled);
use strict;

sub test {
    my $self = shift;

    $self->_buildMocks();

    $self->test_LoggerContextWithParams();

    $self->test_LoggerCommunicationWithParams();
    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_LoggerContextWithParams {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->memory()->get('ShopWithParams');
    my $SUT = $self->memory()->get('SUT');
    my $MethodName = 'MethodName';
    my $FunctionPointer = sub { return 'Function'};
    $SUT->logContext($Shop, $MethodName, $FunctionPointer);

    my $WasCalled = WasCalled($SUT, '_LogContext');
    is($WasCalled, 1, "$SubTestName - test if _LogContext was called");
}

sub test_LoggerCommunicationWithParams {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->memory()->get('SUT');

    my $Name = 'Class::method->Request';
    my $hParams = {'URL' => 'http://external.com/shop/status'};
    my $Category = 'SageOne';
    $SUT->logCommunication($Name, $hParams, $Category, [], 3);

    my $WasCalled = WasCalled($SUT, '_LogCommunication');
    is($WasCalled, 1, "$SubTestName - test if _LogContext was called");
}

#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _buildMocks {
    my $self = shift;

    my $SUT = $self->_createSUT();
    my $ShopWithParams = $self->mockFactory()->buildShop({
            'Alias' => 'TestShop',
            'ProtocolAndServerSSL' => 'http://external/base/url/',
            'Site' => $self->_createSite(),
            'ID' => 18847
        })->getMockObject();
    my $ShopWithoutParams = $self->mockFactory()->buildShop({
            'Alias' => 'TestShop',
            'ProtocolAndServerSSL' => 'http://external/base/url/'
        })->getMockObject();

    $self->memory()->add('SUT', $SUT);
    $self->memory()->add('ShopWithParams', $ShopWithParams);
    $self->memory()->add('ShopWithoutParams', $ShopWithoutParams);
}
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;

    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::SageOne::API::Logger',
                   $aParameterList
              );
    my $hContext = { 'ObjectID' => 18847, 'EntryPoint' => 'MethodName', 'ShopGuid' => 123 };
    $Mockify->addMockWithReturnValueAndParameterCheck('_LogContext', undef, [{'hashref' => $hContext}, 'any']);

    my $aParams = [
                      {'string' => 'Class::method->Request'},
                      {'hashref' => {'URL' => 'http://external.com/shop/status'}},
                      {'string' => 'SageOne'}, {'arrayref' => []}, {'int' => 3}];
    $Mockify->addMethodSpyWithParameterCheck('_LogCommunication', $aParams);
    $Mockify->addMockWithReturnValue('_isLoggingActivated', 1);

    return $Mockify->getMockObject();
}

sub _createSite {
    my $self = shift;
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Object::API::Object::Site',
        {'GUID' => 123}
    );
    return $Mockify->getMockObject();
}
__PACKAGE__->runScript();
