#========================================================================================
# package      DE_EPAGES::Shop::API::Attributes::System_Ext
# state        private
# description  Implements the attributes for shop survey of the "Shop" class.
#========================================================================================
package DE_EPAGES::Shop::API::Attributes::System_Ext;
use base qw( DE_EPAGES::Object::API::BaseAttribute );

use strict;

use DE_EPAGES::Database::API::Connection        qw(GetCurrentDBHandle);
use DE_EPAGES::WebInterface::API::MessageCenter qw(SynchronizeCache);
use DE_EPAGES::DataCache::API::Cache            qw(UpdateCache);

sub getAttributes {
    shift;
    my ($Object, $aNames, $LanguageID) = @_;

    my %Values;
    foreach my $Name (@$aNames) {

        # return undef because we use this not as an real attribute
        # with this pseudo Attribute on the site we reset an attribute on all shops (see below)
        if ($Name eq 'ShopSurveyResetMerchant') {
            $Values{$Name} = undef;
        }

        if ($Name eq 'UnityVideoTutorialFolderID' ) {
            $Values{$Name} = $Object->findChild('UnityVideoTutorials');
        }

    }
    return \%Values;

}

sub setAttributes {
    my $self = shift;
    my ($Object, $hValues, @Parameter) = @_;

    foreach my $Name (keys %$hValues) {

        # special handling to reset the ShopSurveyWaitForMerchant attribute on the shop to 1
        # ShopSurveyResetMerchant is here unsed only as a flag
        if ($Name eq 'ShopSurveyResetMerchant') {

            # only we have a value....
            return unless $hValues->{'ShopSurveyResetMerchant'};

            # reset merchants decision on shop by using SQL
            # delete entry from database because then we hav a default attribute value of 0
            # so we need no initial entries in the database
            my $dbi = GetCurrentDBHandle();
            $dbi->transaction(
                sub {
                    # find shopids for resetting cache later
                    my $sql = <<'END_SQL';
SELECT  ba.objectid, ba.attributeid FROM booleanattribute ba
INNER JOIN object o ON o.alias='ShopSurveyWaitForMerchant' AND ba.attributeid=o.objectid
END_SQL
                    my $aaShopAndAttributeIDs = $dbi->execute($sql);

                    # reset attribute to default value by deleting
                    $sql = <<'END_SQL';
DELETE ba FROM booleanattribute ba
INNER JOIN object o ON o.alias='ShopSurveyWaitForMerchant' AND ba.attributeid=o.objectid
END_SQL
                    $dbi->do($sql, []);

                    # update DAL cache because we have changed the database directly
                    # perform a cache update (see also: DAL_DeleteBooleanAttribute in DE_EPAGES::Object::DAL::DefaultAttribute)
                    my $CacheKey = $dbi->cacheKey;
                    UpdateCache($CacheKey,'AllBooleanAttribute');
                    foreach my $Entry (@$aaShopAndAttributeIDs){
                        UpdateCache($CacheKey, 'InfoBooleanAttribute', join('<||>',$Entry->[0], $Entry->[1]));
                        UpdateCache($CacheKey, 'BooleanAttributeByObjectID', $Entry->[0]);
                        UpdateCache($CacheKey, 'BooleanAttributeByAttributeID', $Entry->[1]);
                    }
                });

            SynchronizeCache();

        }
    }

    return;
}

1;
