#========================================================================================
# package      DE_EPAGES::Shop::API::Attributes::Shop_Ext
# state        private
# description  additional attributes for Shop
#========================================================================================
package DE_EPAGES::ShopCSVExportImport::API::Attributes::Shop_Ext;
use base DE_EPAGES::Object::API::BaseAttribute;

use strict;
use DE_EPAGES::Core::API::File qw ( DeleteFile ExistsFile WriteFile );
use DE_EPAGES::Object::API::Factory qw ( LoadRootObject );
use DE_EPAGES::ShopCSVExportImport::API::Constants qw(IMPORTEXPORTRUN_FILE_PATH);
use DE_EPAGES::WebInterface::API::ApplicationServer qw (GetAppServer);


#========================================================================================
# function     getAttributes
# state        private
#----------------------------------------------------------------------------------------
# syntax       $hValues = $Package->( $Object, $aNames );
# example      # never call getAttributes directly!
#               $Value = $Object->get( $AttributeName );
#----------------------------------------------------------------------------------------
# description  Returns attribute values of an object.
#               Used by <function DE_EPAGES::Object::Object::Object::get>
#----------------------------------------------------------------------------------------
# input        $Object | object | object
# input        $aNames | list of attribute names | ref.array
# return       $hValues | attribute name => value hash | ref.hash
#========================================================================================
sub getAttributes {
    my $self = shift;
    my ($Object, $aNames) = @_;

    my %Values;
    foreach my $Name (@$aNames) {
        if ($Name eq 'IsImportExportRunning') {
            $Values{$Name} = $self->_isImportExportRunning($Object) ;
        }
    }
    return \%Values;
}

#========================================================================================
# function     setAttributes
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Package->setAttributes( $Object, $hValues );
# example      # never call setAttributes directly!
#               $Object->set( { $Name => $Value } );
#----------------------------------------------------------------------------------------
# description  Sets attribute values of an object.
#               Used by <function DE_EPAGES::Object::Object::Object::set>
#----------------------------------------------------------------------------------------
# input        $Object | object | object
# input        $hValues | attribute name => value hash | ref.hash
#========================================================================================
sub setAttributes {
    my $self = shift;
    my ($Object, $hAttributes) = @_;

    foreach my $Name (keys %$hAttributes) {
        my $Value = $hAttributes->{$Name};
        if ($Name eq 'IsImportExportRunning') {
            if($Value ==1 ){
                $self->_createImportExportRunFile($Object);
            }else {
                $self->_deleteImportExportRunFile($Object);

            }
        }
    }
}

sub _createImportExportRunFile {
    my $self = shift;
    my ($Object) = @_;

    my $AppServerIP = '0.0.0.0';
    my $AppServerPort = '0000';

    my $AppServer = GetAppServer();
    if (defined $AppServer) {
        $AppServerIP = $AppServer->address;
        $AppServerPort = $AppServer->port;
    }

    my $FileName = $self->_getImportExportRunFileName($Object);
    my $Content =  "$AppServerIP:$AppServerPort";
    WriteFile($FileName, \$Content, { binary=>1, create_directory=>1});

    return;

}

sub _deleteImportExportRunFile {
    my $self = shift;
    my ($Object) = @_;

    return DeleteFile($self->_getImportExportRunFileName($Object));

}

# test if we have a running import/(export) by checking the existence
# of the file <StoreName>-<ShopGUID> with the Content AppServerIP and AppServerPort
# if the import starts this file is written to $EPAGES_STORES/_ImportExport_
# in case of error the file is cleaned up by the appserver startup hook
sub _isImportExportRunning {
    my $self = shift;
    my ($Object) = @_;

    # test if file exists
    return ExistsFile($self->_getImportExportRunFileName($Object));

}

# returns the file name for running import/export processes
# FileName is the <Storename>-<ShopGUID>
sub _getImportExportRunFileName {
    my $self = shift;
    my ($Object) = @_;

    my $System    = LoadRootObject();
    my $StoreName = $System->get('StoreName');
    my $ShopGUID  = $Object->get('GUID');

    my $FileName = IMPORTEXPORTRUN_FILE_PATH . "$StoreName-$ShopGUID";

    return $FileName ;
}

1;
