#========================================================================================
# package      DE_EPAGES::ShopCSVExportImport::Hooks::AppServerStartup
# state        public
#----------------------------------------------------------------------------------------
# description  Adds actions on startup of the application server
#========================================================================================
package DE_EPAGES::ShopCSVExportImport::Hooks::AppServerStartup;

use strict;
use DE_EPAGES::Core::API::File qw ( DeleteFile ExistsDirectory GetFileContent GetFileNames );
use DE_EPAGES::ShopCSVExportImport::API::Constants qw(IMPORTEXPORTRUN_FILE_PATH);
use DE_EPAGES::WebInterface::API::ApplicationServer qw (GetAppServer);

#========================================================================================
# function     OnAppServerStartup
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnAppServerStartup( $hArgs );
#----------------------------------------------------------------------------------------
# description  Clean up import/export process files.
#               By starting the CSV import or export we write a file to the disc
#               for having a information about a running import/export process.
#               If the removal of this file(s) fails e.g. killed ApplicationServer
#               we have to remove this file by using this hook function
#----------------------------------------------------------------------------------------
# input        $hArgs | hook parameters (currently no used) | ref.hash
#========================================================================================
sub OnAppServerStartup {
    my ($hArgs) = @_;

    # directory not exist; nothing to do
    return unless ExistsDirectory(IMPORTEXPORTRUN_FILE_PATH);

    my $AppServer = GetAppServer();
    return unless defined $AppServer;
    my $AppServerIP   = $AppServer->address;
    my $AppServerPort = $AppServer->port;
    
    # get all files in the directory
    foreach my $File (@{GetFileNames(IMPORTEXPORTRUN_FILE_PATH)}) {
        # get the ip and port from the file (saved as:<ASIP>:<ASPORT> in file ) and 
        # test if we have to delete the orphaned file
        my $rContent = GetFileContent($File);
        DeleteFile($File) if $$rContent =~ m/$AppServerIP:$AppServerPort/;
    }

    return;
}

1;
