package DE_EPAGES::Test::API::Hook;
use base DE_EPAGES::Test::API::StoreUnitTest;

use strict;
use Test::More;
use DE_EPAGES::Cartridge::DAL::Cartridges qw( DAL_GetAllInfoCartridges );
use DE_EPAGES::Core::API::File qw( RunOnGlob );
use DE_EPAGES::Core::API::PerlTools qw( unique );
use DE_EPAGES::Trigger::DAL::Hook qw( DAL_GetAllInfoHookFunctions );

my %IgnoreList = map { $_ => 1 } ('DE_EPAGES::Presentation::Hooks::AppServerStartup', 'DE_EPAGES::ShopCSVExportImport::Hooks::AppServerStartup');

#========================================================================================
# function     test
#----------------------------------------------------------------------------------------
# syntax       $UnitTest->test;
#----------------------------------------------------------------------------------------
# description  search for unused hook modules
#               all perl modules in the Hook directory of all installed cartridges are
#               checked whether or not there exists a hook function in the database that uses it
#========================================================================================
sub test {
    my $self = shift;

    my %HookModulesFromDB = map { $_ => $_ } @{_GetHookModulesFromDB()};
    my $aHookModulesByFiles = _GetHookModulesByFiles();

    my $NoOfHookModulesToTest = 0;
    foreach my $HookModule (@$aHookModulesByFiles) {
        ok( exists $HookModulesFromDB{$HookModule}, "$HookModule has a corresponding hook function in the database." );
        $NoOfHookModulesToTest++;
    }

    plan tests => $NoOfHookModulesToTest;
}

#========================================================================================
sub _GetHookModulesFromDB {

    my @HookModules = ();

    foreach my $HookFunction (map { $_->{'FunctionName'} } @{DAL_GetAllInfoHookFunctions()}) {
        my @parts = split(/::/, $HookFunction);
        pop @parts; # remove function
        push @HookModules, join('::', @parts);
    }

    return [unique(@HookModules)];
}


#========================================================================================
sub _GetHookModulesByFiles {
    # get installed cartridges
    my $ahCartridges = DAL_GetAllInfoCartridges();

    my @HookModules;
    foreach my $CartridgePackage (map { $_->{'Package'} } @$ahCartridges) {
        my $HookDir = $CartridgePackage;
        $HookDir =~ s/::/\//g;
        $HookDir = "$ENV{'EPAGES_CARTRIDGES'}/$HookDir/Hooks";
        next unless -d $HookDir;

        RunOnGlob( $HookDir, '*.pm', sub {
            s/^[\\\/]//;
            s/[\\\/]/::/g;
            s/\.pm$//;
            $_ = $CartridgePackage.'::Hooks::'.$_;
            next if exists $IgnoreList{$_};
            push @HookModules, $_;
        })
    }
    return \@HookModules;
}

1;
